CREATE TABLE "PROJECTS"(
    "UUID" VARCHAR(40) NOT NULL,
    "KEE" VARCHAR(400) NOT NULL,
    "QUALIFIER" VARCHAR(10) NOT NULL,
    "ORGANIZATION_UUID" VARCHAR(40) NOT NULL,
    "NAME" VARCHAR(2000),
    "DESCRIPTION" VARCHAR(2000),
    "PRIVATE" BOOLEAN NOT NULL,
    "TAGS" VARCHAR(500),
    "CREATED_AT" BIGINT,
    "UPDATED_AT" BIGINT NOT NULL
);
ALTER TABLE "PROJECTS" ADD CONSTRAINT "PK_NEW_PROJECTS" PRIMARY KEY("UUID");
CREATE UNIQUE INDEX "UNIQ_PROJECTS_KEE" ON "PROJECTS"("KEE");
CREATE INDEX "IDX_QUALIFIER" ON "PROJECTS"("QUALIFIER");

CREATE TABLE "PROJECT_BRANCHES"(
    "UUID" VARCHAR(50) NOT NULL,
    "PROJECT_UUID" VARCHAR(50) NOT NULL,
    "KEE" VARCHAR(255) NOT NULL,
    "BRANCH_TYPE" VARCHAR(12) NOT NULL,
    "MERGE_BRANCH_UUID" VARCHAR(50),
    "PULL_REQUEST_BINARY" BLOB,
    "MANUAL_BASELINE_ANALYSIS_UUID" VARCHAR(40),
    "CREATED_AT" BIGINT NOT NULL,
    "UPDATED_AT" BIGINT NOT NULL,
    "EXCLUDE_FROM_PURGE" BOOLEAN DEFAULT FALSE NOT NULL,
    "NEED_ISSUE_SYNC" BOOLEAN NOT NULL
);
ALTER TABLE "PROJECT_BRANCHES" ADD CONSTRAINT "PK_PROJECT_BRANCHES" PRIMARY KEY("UUID");
CREATE UNIQUE INDEX "UNIQ_PROJECT_BRANCHES" ON "PROJECT_BRANCHES"("BRANCH_TYPE", "PROJECT_UUID", "KEE");

CREATE TABLE "INTERNAL_PROPERTIES"(
    "KEE" VARCHAR(20) NOT NULL,
    "IS_EMPTY" BOOLEAN NOT NULL,
    "TEXT_VALUE" VARCHAR(4000),
    "CLOB_VALUE" CLOB,
    "CREATED_AT" BIGINT NOT NULL
);
ALTER TABLE "INTERNAL_PROPERTIES" ADD CONSTRAINT "PK_INTERNAL_PROPERTIES" PRIMARY KEY("KEE");

CREATE TABLE "APP_BRANCH_PROJECT_BRANCH"(
    "UUID" VARCHAR(40) NOT NULL,
    "APPLICATION_UUID" VARCHAR(40) NOT NULL,
    "APPLICATION_BRANCH_UUID" VARCHAR(40) NOT NULL,
    "PROJECT_UUID" VARCHAR(40) NOT NULL,
    "PROJECT_BRANCH_UUID" VARCHAR(40) NOT NULL,
    "CREATED_AT" BIGINT NOT NULL
);
ALTER TABLE "APP_BRANCH_PROJECT_BRANCH" ADD CONSTRAINT "PK_APP_BRANCH_PROJECT_BRANCH" PRIMARY KEY("UUID");
CREATE UNIQUE INDEX "UNIQ_APP_BRANCH_PROJ" ON "APP_BRANCH_PROJECT_BRANCH"("APPLICATION_BRANCH_UUID", "PROJECT_BRANCH_UUID");
CREATE INDEX "IDX_ABPB_APP_UUID" ON "APP_BRANCH_PROJECT_BRANCH"("APPLICATION_UUID");
CREATE INDEX "IDX_ABPB_APP_BRANCH_UUID" ON "APP_BRANCH_PROJECT_BRANCH"("APPLICATION_BRANCH_UUID");
CREATE INDEX "IDX_ABPB_PROJ_UUID" ON "APP_BRANCH_PROJECT_BRANCH"("PROJECT_UUID");
CREATE INDEX "IDX_ABPB_PROJ_BRANCH_UUID" ON "APP_BRANCH_PROJECT_BRANCH"("PROJECT_BRANCH_UUID");

CREATE TABLE "APP_PROJECTS"(
    "UUID" VARCHAR(40) NOT NULL,
    "APPLICATION_UUID" VARCHAR(40) NOT NULL,
    "PROJECT_UUID" VARCHAR(40) NOT NULL,
    "CREATED_AT" BIGINT NOT NULL
);
ALTER TABLE "APP_PROJECTS" ADD CONSTRAINT "PK_APP_PROJECTS" PRIMARY KEY("UUID");
CREATE UNIQUE INDEX "UNIQ_APP_PROJECTS" ON "APP_PROJECTS"("APPLICATION_UUID", "PROJECT_UUID");
CREATE INDEX "IDX_APP_PROJ_APPLICATION_UUID" ON "APP_PROJECTS"("APPLICATION_UUID");
CREATE INDEX "IDX_APP_PROJ_PROJECT_UUID" ON "APP_PROJECTS"("PROJECT_UUID");
